@@ -14,6 +14,26 @@ import pytest_html
 from pytest_html import extras
 
 
+@pytest.hookimpl(hookwrapper=True)
+def pytest_runtest_makereport(item, call):
+    pytest_html = item.config.pluginmanager.getplugin("html")
+    outcome = yield
+    report = outcome.get_result()
+    extra = getattr(report, "extra", [])
+    if report.when == "call":
+        # always add url to report
+        # extra.append(pytest_html.extras.url("http://www.example.com/"))
+        # xfail = hasattr(report, "wasxfail")
+        # if (report.skipped and xfail) or (report.failed and not xfail):
+        #     # only add additional html on failure
+        #     extra.append(pytest_html.extras.html("<div>Additional HTML</div>"))
+        # TODO: raise
+        # pass
+        # if item.module.gif_file
+        extra.append(extras.image(item.module.gif_file, mime_type='image/gif', extension='gif'))
+        report.extra = extra
+
+
 @pytest.fixture
 def test_obj(base_url, browser, browser_version, os_version, os_name, remote_flag, testrail_flag, tesults_flag,
              test_run_id, remote_project_name, remote_build_name, testname, reportportal_service, interactivemode_flag,
