@@ -50,6 +50,7 @@ class Mobile_Base_Page(Borg, unittest.TestCase):
             self.browserstack_flag = False
             self.test_run_id = None
             self.start_time = None      # pytest have Unresolved attribute reference if not added
+            self.exceptions = []
             self.test_env = ""          # pytest have Unresolved attribute reference if not added
 
             self.reset()
@@ -155,22 +156,26 @@ class Mobile_Base_Page(Borg, unittest.TestCase):
     def set_directory_structure(self):
         "Setup the required directory structure if it is not already present"
         try:
-            self.screenshots_parent_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), '..', 'screenshots', self.product))
+            self.screenshots_parent_dir = os.path.abspath(
+                os.path.join(os.curdir, 'screenshots', self.product))  # Real screencap folder dir
             if not os.path.exists(self.screenshots_parent_dir):
                 os.makedirs(self.screenshots_parent_dir)
-            self.logs_parent_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), '..', 'log', self.product))
+            self.logs_parent_dir = os.path.abspath(os.path.join(os.curdir, 'log',
+                                                                self.product))  # Real log file dir base on Base_Logging.py constructor
             if not os.path.exists(self.logs_parent_dir):
                 os.makedirs(self.logs_parent_dir)
         except Exception as e:
             self.write("Exception when trying to set directory structure")
             self.write(str(e))
+            self.exceptions.append("Error when setting up the directory structure")
 
     def set_screenshot_dir(self):
         "Set the screenshot directory"
         try:
             self.screenshot_dir = self.get_screenshot_dir()
-            if not os.path.exists(self.screenshot_dir):
+            if not os.path.exists(self.screenshot_dir) and self.screenshot != 'off':
                 os.makedirs(self.screenshot_dir)
+
         except Exception as e:
             self.write("Exception when trying to set screenshot directory")
             self.write(str(e))
@@ -181,7 +186,7 @@ class Mobile_Base_Page(Borg, unittest.TestCase):
         self.testname = self.testname.replace('<', '')
         self.testname = self.testname.replace('>', '')
         # self.screenshot_dir = self.screenshots_parent_dir + os.sep + self.testname
-        self.screenshot_dir = self.screenshots_parent_dir + os.sep + '[' + self.test_env + ']' + self.testname + '_' + self.timestr
+        self.screenshot_dir = self.screenshots_parent_dir + os.sep + '[' + self.test_env + ']' + self.testname + '_' + self.timestr  # Real screencap file dir
         if os.path.exists(self.screenshot_dir):
             for i in range(1, 4096):
                 if os.path.exists(self.screenshot_dir + '_' + str(i)):
